.. _api_ref:

.. currentmodule:: inequality

API reference
=============

.. _inequality_api:

Atkinson Inequality Measures
----------------------------

.. autosummary::
   :toctree: generated/

    atkinson.Atkinson


Gini Inequality Measures
------------------------

.. autosummary::
   :toctree: generated/

    gini.Gini
    gini.Gini_Spatial

Schutz Inequality Measures
--------------------------

.. autosummary::
   :toctree: generated/

    schutz.Schutz
 
Theil Inequality Measures
-------------------------

.. autosummary::
   :toctree: generated/

    theil.Theil 
    theil.TheilD
    theil.TheilDSim

Wolfson Bipolarization Measure
------------------------------
.. autosummary::
   :toctree: generated/

    wolfson.wolfson
    
	     
Pengram
-------

.. autosummary::
   :toctree: generated/

    pen.pen
    pen.pengram

